@@ -136,7 +136,7 @@ plotSpatialLines <- function(SL, xlim = NULL, ylim = NULL,
 setMethod("plot", signature(x = "SpatialLines", y = "missing"),
 	function(x, y, ...) plotSpatialLines(x, ...))
 
-setMethod("coordinates", "Line", function(obj) { cc = obj@coords; row.names(cc) <- NULL; cc })
+setMethod("coordinates", "Line", function(obj) obj@coords)
 setMethod("coordinates", "Lines", function(obj) lapply(obj@Lines, coordinates))
 setMethod("coordinates", "SpatialLines", function(obj) lapply(obj@lines, coordinates))
 
@@ -234,16 +234,18 @@ SpatialLinesLengths = function(SL, longlat) {
 }
 
 setAs("Lines", "SpatialPoints", function(from) {
-		SpatialPoints(do.call(rbind, coordinates(from)))
+		cc = do.call(rbind, coordinates(from))
+		if (!is.null(rownames(cc)))
+			rownames(cc) = make.unique(rownames(cc))
+		SpatialPoints(cc)
 	}
 )
 setAs("SpatialLines", "SpatialPoints", function(from) {
-		SpatialPoints(
-			do.call(rbind,
-				lapply(from@lines, function(x) coordinates(
-						as(x, "SpatialPoints")))),
-			CRS(proj4string(from))
-		)
+		cc = do.call(rbind,
+				lapply(from@lines, function(x) coordinates(as(x, "SpatialPoints"))))
+		if (!is.null(rownames(cc)))
+			rownames(cc) = make.unique(rownames(cc))
+		SpatialPoints(cc, CRS(proj4string(from)))
 	}
 )
 setAs("Lines", "SpatialMultiPoints", function(from) {
@@ -310,3 +312,39 @@ length.SpatialLines = function(x) { length(x@lines) }
 names.SpatialLines = function(x) { 
 	unlist(lapply(x@lines, function(X) X@ID)) 
 }
+
+labels.SpatialLines = function(object, newCRS, side = 1:2, ...) {
+	# 1=below, 2=left, 3=above and 4=right.
+	if (! identical(names(object), c("EW", "NS")))
+		warning("this function is meant to operate on SpatialLines created with sp::gridlines")
+	if (is.projected(object)) {
+		newCRS = object@proj4string
+        gl = spTransform(object, CRS("+init=epsg:4326")) # WGS84
+	} else
+		gl = object
+
+	cc = coordinates(gl)
+	pts = lapply(cc, function(x) do.call(rbind, lapply(x, function(y) y[1,])))
+	lat = pts[[1]][,2]
+	long = pts[[2]][,1]
+
+	object = spTransform(object, newCRS) # may be obsolete
+	cc = coordinates(object)
+	pts = append(
+			lapply(cc, function(x) do.call(rbind, lapply(x, function(y) head(y, 1)))),
+			lapply(cc, function(x) do.call(rbind, lapply(x, function(y) tail(y, 1))))
+		)
+	ang = append(
+		#lapply(cc, function(x) apply(do.call(rbind, lapply(x, function(y) y[2,] - y[1,])), 1,
+		#	function(x) atan2(x[2], x[1])*180/pi))
+		lapply(cc, function(x) apply(do.call(rbind, lapply(x, function(y) apply(head(y, 2), 2, diff))), 1,
+			function(x) atan2(x[2], x[1])*180/pi)),
+		lapply(cc, function(x) apply(do.call(rbind, lapply(x, function(y) apply(tail(y, 2), 2, diff))), 1,
+			function(x) atan2(x[2], x[1])*180/pi))
+		)
+	d = SpatialPoints(do.call(rbind, lapply(pts, function(x) { row.names(x) = NULL; x})))
+	d$srt = c(ang[[1]], ang[[2]] - 90, ang[[3]], ang[[4]] - 90)
+	d$pos = rep(c(2,1,4,3), times = rep(sapply(cc, length),2))
+	d$labels = rep(c(degreeLabelsNS(lat), degreeLabelsEW(long)), 2)
+	d[d$pos %in% side,]
+}
