@@ -8,31 +8,14 @@
 #endif
 /* remember to touch local_stubs.c */
 
-#define SP_VERSION "1.2-0"
+#define SP_VERSION "1.2-2"
 
-#include <S.h>
-
-#ifdef USING_R
 #include <R.h>
 /* RSB 091203 */
 #include <Rdefines.h>
 #define R_OFFSET 1
-/* */
 #include <Rinternals.h>
 #include <Rmath.h>
-#else
-# if (!defined(SPLUS_VERSION) || SPLUS_VERSION < 6000)
-#  error("no SPLUS_VERSION >= 6.0")
-# endif
-# define SEXP s_object *
-# define PROTECT(x) x
-# define UNPROTECT(x)
-# define R_UNIFORM unif_rand(S_evaluator)
-# define R_NORMAL  norm_rand(S_evaluator)
-# define RANDIN seed_in((long *) NULL, S_evaluator)
-# define RANDOUT seed_out((long *) NULL, S_evaluator)
-# define Rprintf printf
-#endif
 
 /* from insiders.c 
 
